@@ -7,10 +7,12 @@ class ReqIFObjectLookup:
     def __init__(
         self,
         data_types_lookup: Dict[str, Any],
+        spec_types_lookup: Dict,
         spec_objects_lookup: Dict[str, ReqIFSpecObject],
         spec_relations_parent_lookup: Dict[str, List[str]],
     ):
         self.data_types_lookup: Dict[str, Any] = data_types_lookup
+        self.spec_types_lookup: Dict = spec_types_lookup
         self.spec_objects_lookup = spec_objects_lookup
         self.spec_relations_parent_lookup = spec_relations_parent_lookup
 
@@ -18,6 +20,7 @@ class ReqIFObjectLookup:
     def empty():
         return ReqIFObjectLookup(
             data_types_lookup={},
+            spec_types_lookup={},
             spec_objects_lookup={},
             spec_relations_parent_lookup={},
         )
@@ -28,6 +31,9 @@ class ReqIFObjectLookup:
     def get_data_type_by_ref(self, ref) -> Any:
         return self.data_types_lookup[ref]
 
+    def get_spec_type_by_ref(self, ref) -> Any:
+        return self.spec_types_lookup[ref]
+
     def get_spec_object_by_ref(self, ref) -> ReqIFSpecObject:
         return self.spec_objects_lookup[ref]
 
